import { AxiosInstance } from 'axios';
declare module 'axios' {
    interface AxiosResponse<T = any> extends Promise<T> {
    }
}
export interface Instance {
    uuid: string;
    namespace: string;
    name: string;
    cpus: number;
    memory: number;
    disk_spec: DiskSpec[];
    ssh_key: string | null;
    node: string;
    power_state: string;
    power_state_previous: string | null;
    power_state_updated: number;
    console_port: number;
    vdi_port: number;
    user_data: string | null;
    state: string;
    state_updated: number;
}
export interface InstanceEvent {
    timestamp: number;
    fqdn: string;
    operation: string;
    phase: string;
    duration: number;
    message: string;
}
interface DiskSpec {
    base: string;
    size: number;
    bus: string;
    type: string;
}
export interface SFNode {
    name: string;
    ip: string;
    lastseen: number;
}
declare type vmAction = 'reboot' | 'poweroff' | 'poweron' | 'pause' | 'unpause';
export declare class Client {
    httpClient: AxiosInstance;
    apiKey: string;
    ns: string;
    tokenExpiry: Date;
    constructor(url: string, apiKey: string, ns?: string);
    connect(): Promise<void>;
    canConnect(): Promise<boolean>;
    authenticate(): Promise<void>;
    private getToken;
    private setTokenExpiry;
    needsTokenRefresh(): boolean;
    listInstances(): Promise<Instance[]>;
    getInstance(uuid: string): Promise<Instance>;
    instanceAction(uuid: string, action: vmAction): Promise<void>;
    getInstanceHistory(uuid: string): Promise<InstanceEvent[]>;
    listNodes(): Promise<SFNode[]>;
}
export {};
